@@ -10,13 +10,11 @@ use 5.008;
 use strict;
 use warnings;
 
-package Dist::Zilla::Plugin::Test::Compile;
-# git description: v2.050-2-g09e54b3
-$Dist::Zilla::Plugin::Test::Compile::VERSION = '2.051';
+package Dist::Zilla::Plugin::Test::Compile; # git description: v2.051-16-g0f87c4a
 # ABSTRACT: Common tests to check syntax of your modules, only using core modules
 # KEYWORDS: plugin test compile verify validate load modules scripts
-# vim: set ts=8 sw=4 tw=78 et :
-
+# vim: set ts=8 sts=4 sw=4 tw=78 et :
+our $VERSION = '2.052';
 use Moose;
 use Path::Tiny;
 use Sub::Exporter::ForMethods 'method_installer'; # method_installer returns a sub.
@@ -40,7 +38,7 @@ with (
     'Dist::Zilla::Role::PrereqSource',
 );
 
-use Moose::Util::TypeConstraints;
+use Moose::Util::TypeConstraints qw(enum role_type);
 use namespace::autoclean;
 
 # -- attributes
@@ -200,7 +198,10 @@ sub munge_file
                 fake_home => \($self->fake_home),
                 needs_display => \($self->needs_display),
                 bail_out_on_fail => \($self->bail_out_on_fail),
-                fail_on_warning => \($self->fail_on_warning),
+                fail_on_warning => \(
+                    $self->fail_on_warning eq 'author' && $self->filename =~ m{^xt/author/}
+                    ? 'all'
+                    : $self->fail_on_warning),
             }
         )
     );
@@ -355,7 +356,7 @@ Dist::Zilla::Plugin::Test::Compile - Common tests to check syntax of your module
 
 =head1 VERSION
 
-version 2.051
+version 2.052
 
 =head1 SYNOPSIS
 
@@ -495,9 +496,19 @@ L<Test::Script>
 
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Jérôme Quelin
+=over 4
+
+=item *
+
+Jérôme Quelin <jquelin@gmail.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -508,21 +519,13 @@ the same terms as the Perl 5 programming language system itself.
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Jérôme Quelin Ahmad M. Zawawi Olivier Mengué Kent Fredric Jesse Luehrs David Golden Randy Stauner Harley Pig Graham Knop fayland Peter Shangov Chris Weyl Ricardo SIGNES Marcel Gruenauer
+=for stopwords Ahmad M. Zawawi Olivier Mengué Kent Fredric Randy Stauner Jesse Luehrs Harley Pig David Golden Graham Knop fayland Peter Shangov Chris Weyl Ricardo SIGNES Marcel Gruenauer
 
 =over 4
 
 =item *
 
-Karen Etheridge <ether@cpan.org>
-
-=item *
-
-Jérôme Quelin <jquelin@gmail.com>
-
-=item *
-
-Ahmad M. Zawawi <azawawi@ubuntu.(none)>
+Ahmad M. Zawawi <ahmad.zawawi@gmail.com>
 
 =item *
 
@@ -534,22 +537,22 @@ Kent Fredric <kentnl@cpan.org>
 
 =item *
 
+Randy Stauner <rwstauner@cpan.org>
+
+=item *
+
 Jesse Luehrs <doy@tozt.net>
 
 =item *
 
-David Golden <dagolden@cpan.org>
-
-=item *
-
-Randy Stauner <randy@magnificent-tears.com>
-
-=item *
-
 Harley Pig <harleypig@gmail.com>
 
 =item *
 
+David Golden <dagolden@cpan.org>
+
+=item *
+
 Graham Knop <haarg@haarg.org>
 
 =item *
